@@ -31,8 +31,10 @@ def process_error_codes(df, output_df, code_columns, cols):
 def reduce_dim(df, columns, dim, pca):
     X = df[columns]
     X = X.fillna(0)
+    temp = list(X.columns)
+    temp.sort()
 
-    group_key = ','.join(columns)
+    group_key = ','.join(temp)
     # print('group_key : ', group_key)
     if group_key not in pca:
         pca[group_key] = PCA(n_components=dim)
@@ -199,7 +201,7 @@ class Data_Preprocessor:
             pca : dict
                 dictionary of PCA-transformers (default: empty dictionary)
             TRAIN : bool
-                default: False for self.mode='predict'
+                default: False
 
         Raises
         ------
@@ -375,6 +377,7 @@ class Data_Preprocessor:
             # print("----->", temp)
 
             # leave in self.pca only important pca transformers
+            # print(self.pca)
             important_pca_keys = get_pca_key_for_features(temp)
             # print(important_pca_keys)
             self.pca = {key: self.pca[key] for key in important_pca_keys}
